'''_1380.py

MeasurementBase
'''


from typing import List

from mastapy._internal import constructor, enum_with_selected_value_runtime, conversion
from mastapy._internal.implicit import list_with_selected_item, overridable
from mastapy.utility.units_and_measurements import (
    _1385, _1377, _1378, _1379,
    _1383, _1384, _1386
)
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy.utility import _1373
from mastapy._internal.cast_exception import CastException
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_MEASUREMENT_BASE = python_net_import('SMT.MastaAPI.Utility.UnitsAndMeasurements', 'MeasurementBase')


__docformat__ = 'restructuredtext en'
__all__ = ('MeasurementBase',)


class MeasurementBase(_0.APIBase):
    '''MeasurementBase

    This is a mastapy class.
    '''

    TYPE = _MEASUREMENT_BASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'MeasurementBase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def name(self) -> 'str':
        '''str: 'Name' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Name

    @property
    def default_unit(self) -> 'list_with_selected_item.ListWithSelectedItem_Unit':
        '''list_with_selected_item.ListWithSelectedItem_Unit: 'DefaultUnit' is the original name of this property.'''

        return constructor.new(list_with_selected_item.ListWithSelectedItem_Unit)(self.wrapped.DefaultUnit) if self.wrapped.DefaultUnit else None

    @default_unit.setter
    def default_unit(self, value: 'list_with_selected_item.ListWithSelectedItem_Unit.implicit_type()'):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_Unit.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_Unit.implicit_type()
        value = wrapper_type[enclosed_type](value.wrapped if value else None)
        self.wrapped.DefaultUnit = value

    @property
    def rounding_digits(self) -> 'int':
        '''int: 'RoundingDigits' is the original name of this property.'''

        return self.wrapped.RoundingDigits

    @rounding_digits.setter
    def rounding_digits(self, value: 'int'):
        self.wrapped.RoundingDigits = int(value) if value else 0

    @property
    def rounding_method(self) -> '_1373.RoundingMethods':
        '''RoundingMethods: 'RoundingMethod' is the original name of this property.'''

        value = conversion.pn_to_mp_enum(self.wrapped.RoundingMethod)
        return constructor.new(_1373.RoundingMethods)(value) if value else None

    @rounding_method.setter
    def rounding_method(self, value: '_1373.RoundingMethods'):
        value = value if value else None
        value = conversion.mp_to_pn_enum(value)
        self.wrapped.RoundingMethod = value

    @property
    def absolute_tolerance(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'AbsoluteTolerance' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.AbsoluteTolerance) if self.wrapped.AbsoluteTolerance else None

    @absolute_tolerance.setter
    def absolute_tolerance(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.AbsoluteTolerance = value

    @property
    def percentage_tolerance(self) -> 'overridable.Overridable_float':
        '''overridable.Overridable_float: 'PercentageTolerance' is the original name of this property.'''

        return constructor.new(overridable.Overridable_float)(self.wrapped.PercentageTolerance) if self.wrapped.PercentageTolerance else None

    @percentage_tolerance.setter
    def percentage_tolerance(self, value: 'overridable.Overridable_float.implicit_type()'):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0.0, is_overridden)
        self.wrapped.PercentageTolerance = value

    @property
    def current_unit(self) -> '_1385.Unit':
        '''Unit: 'CurrentUnit' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _1385.Unit.TYPE not in self.wrapped.CurrentUnit.__class__.__mro__:
            raise CastException('Failed to cast current_unit to Unit. Expected: {}.'.format(self.wrapped.CurrentUnit.__class__.__qualname__))

        return constructor.new_override(self.wrapped.CurrentUnit.__class__)(self.wrapped.CurrentUnit) if self.wrapped.CurrentUnit else None

    @property
    def report_names(self) -> 'List[str]':
        '''List[str]: 'ReportNames' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ReportNames, str)
        return value

    def output_default_report_to(self, file_path: 'str'):
        ''' 'OutputDefaultReportTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else None)

    def get_default_report_with_encoded_images(self) -> 'str':
        ''' 'GetDefaultReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        '''

        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    def output_active_report_to(self, file_path: 'str'):
        ''' 'OutputActiveReportTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else None)

    def output_active_report_as_text_to(self, file_path: 'str'):
        ''' 'OutputActiveReportAsTextTo' is the original name of this method.

        Args:
            file_path (str)
        '''

        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else None)

    def get_active_report_with_encoded_images(self) -> 'str':
        ''' 'GetActiveReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        '''

        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    def output_named_report_to(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(report_name if report_name else None, file_path if file_path else None)

    def output_named_report_as_masta_report(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportAsMastaReport' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(report_name if report_name else None, file_path if file_path else None)

    def output_named_report_as_text_to(self, report_name: 'str', file_path: 'str'):
        ''' 'OutputNamedReportAsTextTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        '''

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(report_name if report_name else None, file_path if file_path else None)

    def get_named_report_with_encoded_images(self, report_name: 'str') -> 'str':
        ''' 'GetNamedReportWithEncodedImages' is the original name of this method.

        Args:
            report_name (str)

        Returns:
            str
        '''

        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(report_name if report_name else None)
        return method_result



'''_2434.py

CVTBeltConnectionSystemDeflection
'''


from mastapy._internal import constructor
from mastapy.system_model.connections_and_sockets import _1982
from mastapy.system_model.analyses_and_results.power_flows import _3772
from mastapy.system_model.analyses_and_results.system_deflections import _2401
from mastapy._internal.python_net import python_net_import

_CVT_BELT_CONNECTION_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections', 'CVTBeltConnectionSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('CVTBeltConnectionSystemDeflection',)


class CVTBeltConnectionSystemDeflection(_2401.BeltConnectionSystemDeflection):
    '''CVTBeltConnectionSystemDeflection

    This is a mastapy class.
    '''

    TYPE = _CVT_BELT_CONNECTION_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CVTBeltConnectionSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def minimum_required_clamping_force(self) -> 'float':
        '''float: 'MinimumRequiredClampingForce' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MinimumRequiredClampingForce

    @property
    def belt_clamping_force_safety_factor(self) -> 'float':
        '''float: 'BeltClampingForceSafetyFactor' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.BeltClampingForceSafetyFactor

    @property
    def total_efficiency(self) -> 'float':
        '''float: 'TotalEfficiency' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.TotalEfficiency

    @property
    def variator_efficiency(self) -> 'float':
        '''float: 'VariatorEfficiency' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.VariatorEfficiency

    @property
    def pump_efficiency(self) -> 'float':
        '''float: 'PumpEfficiency' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PumpEfficiency

    @property
    def connection_design(self) -> '_1982.CVTBeltConnection':
        '''CVTBeltConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1982.CVTBeltConnection)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def power_flow_results(self) -> '_3772.CVTBeltConnectionPowerFlow':
        '''CVTBeltConnectionPowerFlow: 'PowerFlowResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_3772.CVTBeltConnectionPowerFlow)(self.wrapped.PowerFlowResults) if self.wrapped.PowerFlowResults else None



'''_581.py

GearManufacturingConfigurationViewModelPlaceholder
'''


from mastapy.gears.manufacturing.cylindrical import _580
from mastapy._internal.python_net import python_net_import

_GEAR_MANUFACTURING_CONFIGURATION_VIEW_MODEL_PLACEHOLDER = python_net_import('SMT.MastaAPI.Gears.Manufacturing.Cylindrical', 'GearManufacturingConfigurationViewModelPlaceholder')


__docformat__ = 'restructuredtext en'
__all__ = ('GearManufacturingConfigurationViewModelPlaceholder',)


class GearManufacturingConfigurationViewModelPlaceholder(_580.GearManufacturingConfigurationViewModel):
    '''GearManufacturingConfigurationViewModelPlaceholder

    This is a mastapy class.
    '''

    TYPE = _GEAR_MANUFACTURING_CONFIGURATION_VIEW_MODEL_PLACEHOLDER

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GearManufacturingConfigurationViewModelPlaceholder.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_6121.py

ConceptGearSetCompoundDynamicAnalysis
'''


from typing import List

from mastapy.system_model.part_model.gears import _2229
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.dynamic_analyses.compound import _6119, _6120, _6150
from mastapy.system_model.analyses_and_results.dynamic_analyses import _5991
from mastapy._internal.python_net import python_net_import

_CONCEPT_GEAR_SET_COMPOUND_DYNAMIC_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.DynamicAnalyses.Compound', 'ConceptGearSetCompoundDynamicAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('ConceptGearSetCompoundDynamicAnalysis',)


class ConceptGearSetCompoundDynamicAnalysis(_6150.GearSetCompoundDynamicAnalysis):
    '''ConceptGearSetCompoundDynamicAnalysis

    This is a mastapy class.
    '''

    TYPE = _CONCEPT_GEAR_SET_COMPOUND_DYNAMIC_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConceptGearSetCompoundDynamicAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2229.ConceptGearSet':
        '''ConceptGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2229.ConceptGearSet)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2229.ConceptGearSet':
        '''ConceptGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2229.ConceptGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def concept_gears_compound_dynamic_analysis(self) -> 'List[_6119.ConceptGearCompoundDynamicAnalysis]':
        '''List[ConceptGearCompoundDynamicAnalysis]: 'ConceptGearsCompoundDynamicAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConceptGearsCompoundDynamicAnalysis, constructor.new(_6119.ConceptGearCompoundDynamicAnalysis))
        return value

    @property
    def concept_meshes_compound_dynamic_analysis(self) -> 'List[_6120.ConceptGearMeshCompoundDynamicAnalysis]':
        '''List[ConceptGearMeshCompoundDynamicAnalysis]: 'ConceptMeshesCompoundDynamicAnalysis' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ConceptMeshesCompoundDynamicAnalysis, constructor.new(_6120.ConceptGearMeshCompoundDynamicAnalysis))
        return value

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_5991.ConceptGearSetDynamicAnalysis]':
        '''List[ConceptGearSetDynamicAnalysis]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCasesReady, constructor.new(_5991.ConceptGearSetDynamicAnalysis))
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_5991.ConceptGearSetDynamicAnalysis]':
        '''List[ConceptGearSetDynamicAnalysis]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCases, constructor.new(_5991.ConceptGearSetDynamicAnalysis))
        return value



'''_6640.py

SpiralBevelGearMeshLoadCase
'''


from mastapy.system_model.connections_and_sockets.gears import _2032
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6510
from mastapy._internal.python_net import python_net_import

_SPIRAL_BEVEL_GEAR_MESH_LOAD_CASE = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads', 'SpiralBevelGearMeshLoadCase')


__docformat__ = 'restructuredtext en'
__all__ = ('SpiralBevelGearMeshLoadCase',)


class SpiralBevelGearMeshLoadCase(_6510.BevelGearMeshLoadCase):
    '''SpiralBevelGearMeshLoadCase

    This is a mastapy class.
    '''

    TYPE = _SPIRAL_BEVEL_GEAR_MESH_LOAD_CASE

    __hash__ = None

    def __init__(self, instance_to_wrap: 'SpiralBevelGearMeshLoadCase.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_design(self) -> '_2032.SpiralBevelGearMesh':
        '''SpiralBevelGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2032.SpiralBevelGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._461 import CylindricalGearSetRatingOptimisationHelper
    from ._462 import OptimisationResultsPair
    from ._463 import SafetyFactorOptimisationResults
    from ._464 import SafetyFactorOptimisationStepResult
    from ._465 import SafetyFactorOptimisationStepResultAngle
    from ._466 import SafetyFactorOptimisationStepResultNumber
    from ._467 import SafetyFactorOptimisationStepResultShortLength



'''_2346.py

MultibodyDynamicsAnalysis
'''


from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.mbd_analyses import _5154
from mastapy.nodal_analysis.system_solvers import (
    _113, _95, _96, _99,
    _100, _101, _102, _103,
    _104, _105, _106, _111,
    _114
)
from mastapy._internal.cast_exception import CastException
from mastapy.system_model.analyses_and_results.analysis_cases import _7235
from mastapy._internal.python_net import python_net_import

_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses', 'MultibodyDynamicsAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('MultibodyDynamicsAnalysis',)


class MultibodyDynamicsAnalysis(_7235.TimeSeriesLoadAnalysisCase):
    '''MultibodyDynamicsAnalysis

    This is a mastapy class.
    '''

    TYPE = _MULTIBODY_DYNAMICS_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'MultibodyDynamicsAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def percentage_time_spent_in_masta_solver(self) -> 'float':
        '''float: 'PercentageTimeSpentInMASTASolver' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PercentageTimeSpentInMASTASolver

    @property
    def has_interface_analysis_results_available(self) -> 'bool':
        '''bool: 'HasInterfaceAnalysisResultsAvailable' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.HasInterfaceAnalysisResultsAvailable

    @property
    def mbd_options(self) -> '_5154.MBDAnalysisOptions':
        '''MBDAnalysisOptions: 'MBDOptions' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_5154.MBDAnalysisOptions)(self.wrapped.MBDOptions) if self.wrapped.MBDOptions else None

    @property
    def transient_solver(self) -> '_113.TransientSolver':
        '''TransientSolver: 'TransientSolver' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _113.TransientSolver.TYPE not in self.wrapped.TransientSolver.__class__.__mro__:
            raise CastException('Failed to cast transient_solver to TransientSolver. Expected: {}.'.format(self.wrapped.TransientSolver.__class__.__qualname__))

        return constructor.new_override(self.wrapped.TransientSolver.__class__)(self.wrapped.TransientSolver) if self.wrapped.TransientSolver else None

    @property
    def transient_solver_of_type_backward_euler_acceleration_step_halving_transient_solver(self) -> '_95.BackwardEulerAccelerationStepHalvingTransientSolver':
        '''BackwardEulerAccelerationStepHalvingTransientSolver: 'TransientSolver' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _95.BackwardEulerAccelerationStepHalvingTransientSolver.TYPE not in self.wrapped.TransientSolver.__class__.__mro__:
            raise CastException('Failed to cast transient_solver to BackwardEulerAccelerationStepHalvingTransientSolver. Expected: {}.'.format(self.wrapped.TransientSolver.__class__.__qualname__))

        return constructor.new_override(self.wrapped.TransientSolver.__class__)(self.wrapped.TransientSolver) if self.wrapped.TransientSolver else None

    @property
    def transient_solver_of_type_backward_euler_transient_solver(self) -> '_96.BackwardEulerTransientSolver':
        '''BackwardEulerTransientSolver: 'TransientSolver' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _96.BackwardEulerTransientSolver.TYPE not in self.wrapped.TransientSolver.__class__.__mro__:
            raise CastException('Failed to cast transient_solver to BackwardEulerTransientSolver. Expected: {}.'.format(self.wrapped.TransientSolver.__class__.__qualname__))

        return constructor.new_override(self.wrapped.TransientSolver.__class__)(self.wrapped.TransientSolver) if self.wrapped.TransientSolver else None

    @property
    def transient_solver_of_type_internal_transient_solver(self) -> '_99.InternalTransientSolver':
        '''InternalTransientSolver: 'TransientSolver' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _99.InternalTransientSolver.TYPE not in self.wrapped.TransientSolver.__class__.__mro__:
            raise CastException('Failed to cast transient_solver to InternalTransientSolver. Expected: {}.'.format(self.wrapped.TransientSolver.__class__.__qualname__))

        return constructor.new_override(self.wrapped.TransientSolver.__class__)(self.wrapped.TransientSolver) if self.wrapped.TransientSolver else None

    @property
    def transient_solver_of_type_lobatto_iiia_transient_solver(self) -> '_100.LobattoIIIATransientSolver':
        '''LobattoIIIATransientSolver: 'TransientSolver' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _100.LobattoIIIATransientSolver.TYPE not in self.wrapped.TransientSolver.__class__.__mro__:
            raise CastException('Failed to cast transient_solver to LobattoIIIATransientSolver. Expected: {}.'.format(self.wrapped.TransientSolver.__class__.__qualname__))

        return constructor.new_override(self.wrapped.TransientSolver.__class__)(self.wrapped.TransientSolver) if self.wrapped.TransientSolver else None

    @property
    def transient_solver_of_type_lobatto_iiic_transient_solver(self) -> '_101.LobattoIIICTransientSolver':
        '''LobattoIIICTransientSolver: 'TransientSolver' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _101.LobattoIIICTransientSolver.TYPE not in self.wrapped.TransientSolver.__class__.__mro__:
            raise CastException('Failed to cast transient_solver to LobattoIIICTransientSolver. Expected: {}.'.format(self.wrapped.TransientSolver.__class__.__qualname__))

        return constructor.new_override(self.wrapped.TransientSolver.__class__)(self.wrapped.TransientSolver) if self.wrapped.TransientSolver else None

    @property
    def transient_solver_of_type_newmark_acceleration_transient_solver(self) -> '_102.NewmarkAccelerationTransientSolver':
        '''NewmarkAccelerationTransientSolver: 'TransientSolver' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _102.NewmarkAccelerationTransientSolver.TYPE not in self.wrapped.TransientSolver.__class__.__mro__:
            raise CastException('Failed to cast transient_solver to NewmarkAccelerationTransientSolver. Expected: {}.'.format(self.wrapped.TransientSolver.__class__.__qualname__))

        return constructor.new_override(self.wrapped.TransientSolver.__class__)(self.wrapped.TransientSolver) if self.wrapped.TransientSolver else None

    @property
    def transient_solver_of_type_newmark_transient_solver(self) -> '_103.NewmarkTransientSolver':
        '''NewmarkTransientSolver: 'TransientSolver' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _103.NewmarkTransientSolver.TYPE not in self.wrapped.TransientSolver.__class__.__mro__:
            raise CastException('Failed to cast transient_solver to NewmarkTransientSolver. Expected: {}.'.format(self.wrapped.TransientSolver.__class__.__qualname__))

        return constructor.new_override(self.wrapped.TransientSolver.__class__)(self.wrapped.TransientSolver) if self.wrapped.TransientSolver else None

    @property
    def transient_solver_of_type_semi_implicit_transient_solver(self) -> '_104.SemiImplicitTransientSolver':
        '''SemiImplicitTransientSolver: 'TransientSolver' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _104.SemiImplicitTransientSolver.TYPE not in self.wrapped.TransientSolver.__class__.__mro__:
            raise CastException('Failed to cast transient_solver to SemiImplicitTransientSolver. Expected: {}.'.format(self.wrapped.TransientSolver.__class__.__qualname__))

        return constructor.new_override(self.wrapped.TransientSolver.__class__)(self.wrapped.TransientSolver) if self.wrapped.TransientSolver else None

    @property
    def transient_solver_of_type_simple_acceleration_based_step_halving_transient_solver(self) -> '_105.SimpleAccelerationBasedStepHalvingTransientSolver':
        '''SimpleAccelerationBasedStepHalvingTransientSolver: 'TransientSolver' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _105.SimpleAccelerationBasedStepHalvingTransientSolver.TYPE not in self.wrapped.TransientSolver.__class__.__mro__:
            raise CastException('Failed to cast transient_solver to SimpleAccelerationBasedStepHalvingTransientSolver. Expected: {}.'.format(self.wrapped.TransientSolver.__class__.__qualname__))

        return constructor.new_override(self.wrapped.TransientSolver.__class__)(self.wrapped.TransientSolver) if self.wrapped.TransientSolver else None

    @property
    def transient_solver_of_type_simple_velocity_based_step_halving_transient_solver(self) -> '_106.SimpleVelocityBasedStepHalvingTransientSolver':
        '''SimpleVelocityBasedStepHalvingTransientSolver: 'TransientSolver' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _106.SimpleVelocityBasedStepHalvingTransientSolver.TYPE not in self.wrapped.TransientSolver.__class__.__mro__:
            raise CastException('Failed to cast transient_solver to SimpleVelocityBasedStepHalvingTransientSolver. Expected: {}.'.format(self.wrapped.TransientSolver.__class__.__qualname__))

        return constructor.new_override(self.wrapped.TransientSolver.__class__)(self.wrapped.TransientSolver) if self.wrapped.TransientSolver else None

    @property
    def transient_solver_of_type_step_halving_transient_solver(self) -> '_111.StepHalvingTransientSolver':
        '''StepHalvingTransientSolver: 'TransientSolver' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _111.StepHalvingTransientSolver.TYPE not in self.wrapped.TransientSolver.__class__.__mro__:
            raise CastException('Failed to cast transient_solver to StepHalvingTransientSolver. Expected: {}.'.format(self.wrapped.TransientSolver.__class__.__qualname__))

        return constructor.new_override(self.wrapped.TransientSolver.__class__)(self.wrapped.TransientSolver) if self.wrapped.TransientSolver else None

    @property
    def transient_solver_of_type_wilson_theta_transient_solver(self) -> '_114.WilsonThetaTransientSolver':
        '''WilsonThetaTransientSolver: 'TransientSolver' is the original name of this property.

        Note:
            This property is readonly.
        '''

        if _114.WilsonThetaTransientSolver.TYPE not in self.wrapped.TransientSolver.__class__.__mro__:
            raise CastException('Failed to cast transient_solver to WilsonThetaTransientSolver. Expected: {}.'.format(self.wrapped.TransientSolver.__class__.__qualname__))

        return constructor.new_override(self.wrapped.TransientSolver.__class__)(self.wrapped.TransientSolver) if self.wrapped.TransientSolver else None



'''_1134.py

ConicalMeshFEModel
'''


from mastapy.gears.fe_model import _1127
from mastapy._internal.python_net import python_net_import

_CONICAL_MESH_FE_MODEL = python_net_import('SMT.MastaAPI.Gears.FEModel.Conical', 'ConicalMeshFEModel')


__docformat__ = 'restructuredtext en'
__all__ = ('ConicalMeshFEModel',)


class ConicalMeshFEModel(_1127.GearMeshFEModel):
    '''ConicalMeshFEModel

    This is a mastapy class.
    '''

    TYPE = _CONICAL_MESH_FE_MODEL

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ConicalMeshFEModel.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_189.py

ElementPropertiesWithMaterial
'''


from mastapy._internal.implicit import list_with_selected_item
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy._internal import constructor
from mastapy.nodal_analysis.dev_tools_analyses.full_fe_reporting import _181
from mastapy._internal.python_net import python_net_import

_ELEMENT_PROPERTIES_WITH_MATERIAL = python_net_import('SMT.MastaAPI.NodalAnalysis.DevToolsAnalyses.FullFEReporting', 'ElementPropertiesWithMaterial')


__docformat__ = 'restructuredtext en'
__all__ = ('ElementPropertiesWithMaterial',)


class ElementPropertiesWithMaterial(_181.ElementPropertiesBase):
    '''ElementPropertiesWithMaterial

    This is a mastapy class.
    '''

    TYPE = _ELEMENT_PROPERTIES_WITH_MATERIAL

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ElementPropertiesWithMaterial.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def material_id(self) -> 'list_with_selected_item.ListWithSelectedItem_int':
        '''list_with_selected_item.ListWithSelectedItem_int: 'MaterialID' is the original name of this property.'''

        return constructor.new(list_with_selected_item.ListWithSelectedItem_int)(self.wrapped.MaterialID) if self.wrapped.MaterialID else None

    @material_id.setter
    def material_id(self, value: 'list_with_selected_item.ListWithSelectedItem_int.implicit_type()'):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_int.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_int.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0)
        self.wrapped.MaterialID = value

    @property
    def material_coordinate_system_id(self) -> 'list_with_selected_item.ListWithSelectedItem_int':
        '''list_with_selected_item.ListWithSelectedItem_int: 'MaterialCoordinateSystemID' is the original name of this property.'''

        return constructor.new(list_with_selected_item.ListWithSelectedItem_int)(self.wrapped.MaterialCoordinateSystemID) if self.wrapped.MaterialCoordinateSystemID else None

    @material_coordinate_system_id.setter
    def material_coordinate_system_id(self, value: 'list_with_selected_item.ListWithSelectedItem_int.implicit_type()'):
        wrapper_type = list_with_selected_item.ListWithSelectedItem_int.wrapper_type()
        enclosed_type = list_with_selected_item.ListWithSelectedItem_int.implicit_type()
        value = wrapper_type[enclosed_type](enclosed_type(value) if value else 0)
        self.wrapped.MaterialCoordinateSystemID = value



'''__init__.py'''


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._3336 import AbstractAssemblyCompoundSteadyStateSynchronousResponse
    from ._3337 import AbstractShaftCompoundSteadyStateSynchronousResponse
    from ._3338 import AbstractShaftOrHousingCompoundSteadyStateSynchronousResponse
    from ._3339 import AbstractShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse
    from ._3340 import AGMAGleasonConicalGearCompoundSteadyStateSynchronousResponse
    from ._3341 import AGMAGleasonConicalGearMeshCompoundSteadyStateSynchronousResponse
    from ._3342 import AGMAGleasonConicalGearSetCompoundSteadyStateSynchronousResponse
    from ._3343 import AssemblyCompoundSteadyStateSynchronousResponse
    from ._3344 import BearingCompoundSteadyStateSynchronousResponse
    from ._3345 import BeltConnectionCompoundSteadyStateSynchronousResponse
    from ._3346 import BeltDriveCompoundSteadyStateSynchronousResponse
    from ._3347 import BevelDifferentialGearCompoundSteadyStateSynchronousResponse
    from ._3348 import BevelDifferentialGearMeshCompoundSteadyStateSynchronousResponse
    from ._3349 import BevelDifferentialGearSetCompoundSteadyStateSynchronousResponse
    from ._3350 import BevelDifferentialPlanetGearCompoundSteadyStateSynchronousResponse
    from ._3351 import BevelDifferentialSunGearCompoundSteadyStateSynchronousResponse
    from ._3352 import BevelGearCompoundSteadyStateSynchronousResponse
    from ._3353 import BevelGearMeshCompoundSteadyStateSynchronousResponse
    from ._3354 import BevelGearSetCompoundSteadyStateSynchronousResponse
    from ._3355 import BoltCompoundSteadyStateSynchronousResponse
    from ._3356 import BoltedJointCompoundSteadyStateSynchronousResponse
    from ._3357 import ClutchCompoundSteadyStateSynchronousResponse
    from ._3358 import ClutchConnectionCompoundSteadyStateSynchronousResponse
    from ._3359 import ClutchHalfCompoundSteadyStateSynchronousResponse
    from ._3360 import CoaxialConnectionCompoundSteadyStateSynchronousResponse
    from ._3361 import ComponentCompoundSteadyStateSynchronousResponse
    from ._3362 import ConceptCouplingCompoundSteadyStateSynchronousResponse
    from ._3363 import ConceptCouplingConnectionCompoundSteadyStateSynchronousResponse
    from ._3364 import ConceptCouplingHalfCompoundSteadyStateSynchronousResponse
    from ._3365 import ConceptGearCompoundSteadyStateSynchronousResponse
    from ._3366 import ConceptGearMeshCompoundSteadyStateSynchronousResponse
    from ._3367 import ConceptGearSetCompoundSteadyStateSynchronousResponse
    from ._3368 import ConicalGearCompoundSteadyStateSynchronousResponse
    from ._3369 import ConicalGearMeshCompoundSteadyStateSynchronousResponse
    from ._3370 import ConicalGearSetCompoundSteadyStateSynchronousResponse
    from ._3371 import ConnectionCompoundSteadyStateSynchronousResponse
    from ._3372 import ConnectorCompoundSteadyStateSynchronousResponse
    from ._3373 import CouplingCompoundSteadyStateSynchronousResponse
    from ._3374 import CouplingConnectionCompoundSteadyStateSynchronousResponse
    from ._3375 import CouplingHalfCompoundSteadyStateSynchronousResponse
    from ._3376 import CVTBeltConnectionCompoundSteadyStateSynchronousResponse
    from ._3377 import CVTCompoundSteadyStateSynchronousResponse
    from ._3378 import CVTPulleyCompoundSteadyStateSynchronousResponse
    from ._3379 import CycloidalAssemblyCompoundSteadyStateSynchronousResponse
    from ._3380 import CycloidalDiscCentralBearingConnectionCompoundSteadyStateSynchronousResponse
    from ._3381 import CycloidalDiscCompoundSteadyStateSynchronousResponse
    from ._3382 import CycloidalDiscPlanetaryBearingConnectionCompoundSteadyStateSynchronousResponse
    from ._3383 import CylindricalGearCompoundSteadyStateSynchronousResponse
    from ._3384 import CylindricalGearMeshCompoundSteadyStateSynchronousResponse
    from ._3385 import CylindricalGearSetCompoundSteadyStateSynchronousResponse
    from ._3386 import CylindricalPlanetGearCompoundSteadyStateSynchronousResponse
    from ._3387 import DatumCompoundSteadyStateSynchronousResponse
    from ._3388 import ExternalCADModelCompoundSteadyStateSynchronousResponse
    from ._3389 import FaceGearCompoundSteadyStateSynchronousResponse
    from ._3390 import FaceGearMeshCompoundSteadyStateSynchronousResponse
    from ._3391 import FaceGearSetCompoundSteadyStateSynchronousResponse
    from ._3392 import FEPartCompoundSteadyStateSynchronousResponse
    from ._3393 import FlexiblePinAssemblyCompoundSteadyStateSynchronousResponse
    from ._3394 import GearCompoundSteadyStateSynchronousResponse
    from ._3395 import GearMeshCompoundSteadyStateSynchronousResponse
    from ._3396 import GearSetCompoundSteadyStateSynchronousResponse
    from ._3397 import GuideDxfModelCompoundSteadyStateSynchronousResponse
    from ._3398 import HypoidGearCompoundSteadyStateSynchronousResponse
    from ._3399 import HypoidGearMeshCompoundSteadyStateSynchronousResponse
    from ._3400 import HypoidGearSetCompoundSteadyStateSynchronousResponse
    from ._3401 import InterMountableComponentConnectionCompoundSteadyStateSynchronousResponse
    from ._3402 import KlingelnbergCycloPalloidConicalGearCompoundSteadyStateSynchronousResponse
    from ._3403 import KlingelnbergCycloPalloidConicalGearMeshCompoundSteadyStateSynchronousResponse
    from ._3404 import KlingelnbergCycloPalloidConicalGearSetCompoundSteadyStateSynchronousResponse
    from ._3405 import KlingelnbergCycloPalloidHypoidGearCompoundSteadyStateSynchronousResponse
    from ._3406 import KlingelnbergCycloPalloidHypoidGearMeshCompoundSteadyStateSynchronousResponse
    from ._3407 import KlingelnbergCycloPalloidHypoidGearSetCompoundSteadyStateSynchronousResponse
    from ._3408 import KlingelnbergCycloPalloidSpiralBevelGearCompoundSteadyStateSynchronousResponse
    from ._3409 import KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSteadyStateSynchronousResponse
    from ._3410 import KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponse
    from ._3411 import MassDiscCompoundSteadyStateSynchronousResponse
    from ._3412 import MeasurementComponentCompoundSteadyStateSynchronousResponse
    from ._3413 import MountableComponentCompoundSteadyStateSynchronousResponse
    from ._3414 import OilSealCompoundSteadyStateSynchronousResponse
    from ._3415 import PartCompoundSteadyStateSynchronousResponse
    from ._3416 import PartToPartShearCouplingCompoundSteadyStateSynchronousResponse
    from ._3417 import PartToPartShearCouplingConnectionCompoundSteadyStateSynchronousResponse
    from ._3418 import PartToPartShearCouplingHalfCompoundSteadyStateSynchronousResponse
    from ._3419 import PlanetaryConnectionCompoundSteadyStateSynchronousResponse
    from ._3420 import PlanetaryGearSetCompoundSteadyStateSynchronousResponse
    from ._3421 import PlanetCarrierCompoundSteadyStateSynchronousResponse
    from ._3422 import PointLoadCompoundSteadyStateSynchronousResponse
    from ._3423 import PowerLoadCompoundSteadyStateSynchronousResponse
    from ._3424 import PulleyCompoundSteadyStateSynchronousResponse
    from ._3425 import RingPinsCompoundSteadyStateSynchronousResponse
    from ._3426 import RingPinsToDiscConnectionCompoundSteadyStateSynchronousResponse
    from ._3427 import RollingRingAssemblyCompoundSteadyStateSynchronousResponse
    from ._3428 import RollingRingCompoundSteadyStateSynchronousResponse
    from ._3429 import RollingRingConnectionCompoundSteadyStateSynchronousResponse
    from ._3430 import RootAssemblyCompoundSteadyStateSynchronousResponse
    from ._3431 import ShaftCompoundSteadyStateSynchronousResponse
    from ._3432 import ShaftHubConnectionCompoundSteadyStateSynchronousResponse
    from ._3433 import ShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse
    from ._3434 import SpecialisedAssemblyCompoundSteadyStateSynchronousResponse
    from ._3435 import SpiralBevelGearCompoundSteadyStateSynchronousResponse
    from ._3436 import SpiralBevelGearMeshCompoundSteadyStateSynchronousResponse
    from ._3437 import SpiralBevelGearSetCompoundSteadyStateSynchronousResponse
    from ._3438 import SpringDamperCompoundSteadyStateSynchronousResponse
    from ._3439 import SpringDamperConnectionCompoundSteadyStateSynchronousResponse
    from ._3440 import SpringDamperHalfCompoundSteadyStateSynchronousResponse
    from ._3441 import StraightBevelDiffGearCompoundSteadyStateSynchronousResponse
    from ._3442 import StraightBevelDiffGearMeshCompoundSteadyStateSynchronousResponse
    from ._3443 import StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponse
    from ._3444 import StraightBevelGearCompoundSteadyStateSynchronousResponse
    from ._3445 import StraightBevelGearMeshCompoundSteadyStateSynchronousResponse
    from ._3446 import StraightBevelGearSetCompoundSteadyStateSynchronousResponse
    from ._3447 import StraightBevelPlanetGearCompoundSteadyStateSynchronousResponse
    from ._3448 import StraightBevelSunGearCompoundSteadyStateSynchronousResponse
    from ._3449 import SynchroniserCompoundSteadyStateSynchronousResponse
    from ._3450 import SynchroniserHalfCompoundSteadyStateSynchronousResponse
    from ._3451 import SynchroniserPartCompoundSteadyStateSynchronousResponse
    from ._3452 import SynchroniserSleeveCompoundSteadyStateSynchronousResponse
    from ._3453 import TorqueConverterCompoundSteadyStateSynchronousResponse
    from ._3454 import TorqueConverterConnectionCompoundSteadyStateSynchronousResponse
    from ._3455 import TorqueConverterPumpCompoundSteadyStateSynchronousResponse
    from ._3456 import TorqueConverterTurbineCompoundSteadyStateSynchronousResponse
    from ._3457 import UnbalancedMassCompoundSteadyStateSynchronousResponse
    from ._3458 import VirtualComponentCompoundSteadyStateSynchronousResponse
    from ._3459 import WormGearCompoundSteadyStateSynchronousResponse
    from ._3460 import WormGearMeshCompoundSteadyStateSynchronousResponse
    from ._3461 import WormGearSetCompoundSteadyStateSynchronousResponse
    from ._3462 import ZerolBevelGearCompoundSteadyStateSynchronousResponse
    from ._3463 import ZerolBevelGearMeshCompoundSteadyStateSynchronousResponse
    from ._3464 import ZerolBevelGearSetCompoundSteadyStateSynchronousResponse



'''_3576.py

StraightBevelGearMeshStabilityAnalysis
'''


from mastapy.system_model.connections_and_sockets.gears import _2036
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.static_loads import _6649
from mastapy.system_model.analyses_and_results.stability_analyses import _3481
from mastapy._internal.python_net import python_net_import

_STRAIGHT_BEVEL_GEAR_MESH_STABILITY_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.StabilityAnalyses', 'StraightBevelGearMeshStabilityAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('StraightBevelGearMeshStabilityAnalysis',)


class StraightBevelGearMeshStabilityAnalysis(_3481.BevelGearMeshStabilityAnalysis):
    '''StraightBevelGearMeshStabilityAnalysis

    This is a mastapy class.
    '''

    TYPE = _STRAIGHT_BEVEL_GEAR_MESH_STABILITY_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'StraightBevelGearMeshStabilityAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_design(self) -> '_2036.StraightBevelGearMesh':
        '''StraightBevelGearMesh: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2036.StraightBevelGearMesh)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None

    @property
    def connection_load_case(self) -> '_6649.StraightBevelGearMeshLoadCase':
        '''StraightBevelGearMeshLoadCase: 'ConnectionLoadCase' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_6649.StraightBevelGearMeshLoadCase)(self.wrapped.ConnectionLoadCase) if self.wrapped.ConnectionLoadCase else None



'''_6267.py

CVTBeltConnectionCriticalSpeedAnalysis
'''


from mastapy.system_model.connections_and_sockets import _1982
from mastapy._internal import constructor
from mastapy.system_model.analyses_and_results.critical_speed_analyses import _6234
from mastapy._internal.python_net import python_net_import

_CVT_BELT_CONNECTION_CRITICAL_SPEED_ANALYSIS = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.CriticalSpeedAnalyses', 'CVTBeltConnectionCriticalSpeedAnalysis')


__docformat__ = 'restructuredtext en'
__all__ = ('CVTBeltConnectionCriticalSpeedAnalysis',)


class CVTBeltConnectionCriticalSpeedAnalysis(_6234.BeltConnectionCriticalSpeedAnalysis):
    '''CVTBeltConnectionCriticalSpeedAnalysis

    This is a mastapy class.
    '''

    TYPE = _CVT_BELT_CONNECTION_CRITICAL_SPEED_ANALYSIS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CVTBeltConnectionCriticalSpeedAnalysis.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def connection_design(self) -> '_1982.CVTBeltConnection':
        '''CVTBeltConnection: 'ConnectionDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1982.CVTBeltConnection)(self.wrapped.ConnectionDesign) if self.wrapped.ConnectionDesign else None



'''_432.py

CylindricalRateableMesh
'''


from mastapy.gears.rating import _332
from mastapy._internal.python_net import python_net_import

_CYLINDRICAL_RATEABLE_MESH = python_net_import('SMT.MastaAPI.Gears.Rating.Cylindrical', 'CylindricalRateableMesh')


__docformat__ = 'restructuredtext en'
__all__ = ('CylindricalRateableMesh',)


class CylindricalRateableMesh(_332.RateableMesh):
    '''CylindricalRateableMesh

    This is a mastapy class.
    '''

    TYPE = _CYLINDRICAL_RATEABLE_MESH

    __hash__ = None

    def __init__(self, instance_to_wrap: 'CylindricalRateableMesh.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()



'''_1095.py

KimosBevelHypoidSingleLoadCaseResultsData
'''


from typing import List

from PIL.Image import Image

from mastapy._internal import constructor, conversion
from mastapy.gears.gear_designs.conical import _1096
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_KIMOS_BEVEL_HYPOID_SINGLE_LOAD_CASE_RESULTS_DATA = python_net_import('SMT.MastaAPI.Gears.GearDesigns.Conical', 'KimosBevelHypoidSingleLoadCaseResultsData')


__docformat__ = 'restructuredtext en'
__all__ = ('KimosBevelHypoidSingleLoadCaseResultsData',)


class KimosBevelHypoidSingleLoadCaseResultsData(_0.APIBase):
    '''KimosBevelHypoidSingleLoadCaseResultsData

    This is a mastapy class.
    '''

    TYPE = _KIMOS_BEVEL_HYPOID_SINGLE_LOAD_CASE_RESULTS_DATA

    __hash__ = None

    def __init__(self, instance_to_wrap: 'KimosBevelHypoidSingleLoadCaseResultsData.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def average_mesh_stiffness_per_unit_face_width(self) -> 'float':
        '''float: 'AverageMeshStiffnessPerUnitFaceWidth' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.AverageMeshStiffnessPerUnitFaceWidth

    @property
    def maximum_contact_pressure(self) -> 'float':
        '''float: 'MaximumContactPressure' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumContactPressure

    @property
    def maximum_pinion_root_stress(self) -> 'float':
        '''float: 'MaximumPinionRootStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumPinionRootStress

    @property
    def maximum_wheel_root_stress(self) -> 'float':
        '''float: 'MaximumWheelRootStress' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumWheelRootStress

    @property
    def maximum_flash_temperature(self) -> 'float':
        '''float: 'MaximumFlashTemperature' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumFlashTemperature

    @property
    def maximum_friction_coefficient(self) -> 'float':
        '''float: 'MaximumFrictionCoefficient' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumFrictionCoefficient

    @property
    def maximum_sliding_velocity(self) -> 'float':
        '''float: 'MaximumSlidingVelocity' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.MaximumSlidingVelocity

    @property
    def peak_to_peak_te_linear_loaded(self) -> 'float':
        '''float: 'PeakToPeakTELinearLoaded' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PeakToPeakTELinearLoaded

    @property
    def peak_to_peak_te_linear_unloaded(self) -> 'float':
        '''float: 'PeakToPeakTELinearUnloaded' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.PeakToPeakTELinearUnloaded

    @property
    def efficiency(self) -> 'float':
        '''float: 'Efficiency' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.Efficiency

    @property
    def contact_ratio_under_load(self) -> 'float':
        '''float: 'ContactRatioUnderLoad' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return self.wrapped.ContactRatioUnderLoad

    @property
    def contact_pressure_chart(self) -> 'Image':
        '''Image: 'ContactPressureChart' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_smt_bitmap(self.wrapped.ContactPressureChart)
        return value

    @property
    def pinion_root_stress_chart(self) -> 'Image':
        '''Image: 'PinionRootStressChart' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_smt_bitmap(self.wrapped.PinionRootStressChart)
        return value

    @property
    def wheel_root_stress_chart(self) -> 'Image':
        '''Image: 'WheelRootStressChart' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_smt_bitmap(self.wrapped.WheelRootStressChart)
        return value

    @property
    def sliding_velocity_chart(self) -> 'Image':
        '''Image: 'SlidingVelocityChart' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_smt_bitmap(self.wrapped.SlidingVelocityChart)
        return value

    @property
    def flash_temperature_chart(self) -> 'Image':
        '''Image: 'FlashTemperatureChart' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_smt_bitmap(self.wrapped.FlashTemperatureChart)
        return value

    @property
    def friction_coefficient_chart(self) -> 'Image':
        '''Image: 'FrictionCoefficientChart' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_smt_bitmap(self.wrapped.FrictionCoefficientChart)
        return value

    @property
    def pressure_velocity_pv_chart(self) -> 'Image':
        '''Image: 'PressureVelocityPVChart' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_smt_bitmap(self.wrapped.PressureVelocityPVChart)
        return value

    @property
    def single_rotation_angle_results(self) -> 'List[_1096.KimosBevelHypoidSingleRotationAngleResult]':
        '''List[KimosBevelHypoidSingleRotationAngleResult]: 'SingleRotationAngleResults' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.SingleRotationAngleResults, constructor.new(_1096.KimosBevelHypoidSingleRotationAngleResult))
        return value



'''_2683.py

ZerolBevelGearSetCompoundSystemDeflection
'''


from typing import List

from mastapy.system_model.part_model.gears import _2261
from mastapy._internal import constructor, conversion
from mastapy.system_model.analyses_and_results.system_deflections.compound import _2681, _2682, _2571
from mastapy.system_model.analyses_and_results.system_deflections import _2542
from mastapy._internal.python_net import python_net_import

_ZEROL_BEVEL_GEAR_SET_COMPOUND_SYSTEM_DEFLECTION = python_net_import('SMT.MastaAPI.SystemModel.AnalysesAndResults.SystemDeflections.Compound', 'ZerolBevelGearSetCompoundSystemDeflection')


__docformat__ = 'restructuredtext en'
__all__ = ('ZerolBevelGearSetCompoundSystemDeflection',)


class ZerolBevelGearSetCompoundSystemDeflection(_2571.BevelGearSetCompoundSystemDeflection):
    '''ZerolBevelGearSetCompoundSystemDeflection

    This is a mastapy class.
    '''

    TYPE = _ZEROL_BEVEL_GEAR_SET_COMPOUND_SYSTEM_DEFLECTION

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ZerolBevelGearSetCompoundSystemDeflection.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def component_design(self) -> '_2261.ZerolBevelGearSet':
        '''ZerolBevelGearSet: 'ComponentDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2261.ZerolBevelGearSet)(self.wrapped.ComponentDesign) if self.wrapped.ComponentDesign else None

    @property
    def assembly_design(self) -> '_2261.ZerolBevelGearSet':
        '''ZerolBevelGearSet: 'AssemblyDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_2261.ZerolBevelGearSet)(self.wrapped.AssemblyDesign) if self.wrapped.AssemblyDesign else None

    @property
    def zerol_bevel_gears_compound_system_deflection(self) -> 'List[_2681.ZerolBevelGearCompoundSystemDeflection]':
        '''List[ZerolBevelGearCompoundSystemDeflection]: 'ZerolBevelGearsCompoundSystemDeflection' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ZerolBevelGearsCompoundSystemDeflection, constructor.new(_2681.ZerolBevelGearCompoundSystemDeflection))
        return value

    @property
    def zerol_bevel_meshes_compound_system_deflection(self) -> 'List[_2682.ZerolBevelGearMeshCompoundSystemDeflection]':
        '''List[ZerolBevelGearMeshCompoundSystemDeflection]: 'ZerolBevelMeshesCompoundSystemDeflection' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.ZerolBevelMeshesCompoundSystemDeflection, constructor.new(_2682.ZerolBevelGearMeshCompoundSystemDeflection))
        return value

    @property
    def assembly_analysis_cases_ready(self) -> 'List[_2542.ZerolBevelGearSetSystemDeflection]':
        '''List[ZerolBevelGearSetSystemDeflection]: 'AssemblyAnalysisCasesReady' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCasesReady, constructor.new(_2542.ZerolBevelGearSetSystemDeflection))
        return value

    @property
    def assembly_analysis_cases(self) -> 'List[_2542.ZerolBevelGearSetSystemDeflection]':
        '''List[ZerolBevelGearSetSystemDeflection]: 'AssemblyAnalysisCases' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.AssemblyAnalysisCases, constructor.new(_2542.ZerolBevelGearSetSystemDeflection))
        return value



'''_2273.py

GearMaterialExpertSystemMaterialDetails
'''


from mastapy._internal import constructor
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_GEAR_MATERIAL_EXPERT_SYSTEM_MATERIAL_DETAILS = python_net_import('SMT.MastaAPI.SystemModel.PartModel.Gears.Materials', 'GearMaterialExpertSystemMaterialDetails')


__docformat__ = 'restructuredtext en'
__all__ = ('GearMaterialExpertSystemMaterialDetails',)


class GearMaterialExpertSystemMaterialDetails(_0.APIBase):
    '''GearMaterialExpertSystemMaterialDetails

    This is a mastapy class.
    '''

    TYPE = _GEAR_MATERIAL_EXPERT_SYSTEM_MATERIAL_DETAILS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'GearMaterialExpertSystemMaterialDetails.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def bar_length(self) -> 'float':
        '''float: 'BarLength' is the original name of this property.'''

        return self.wrapped.BarLength

    @bar_length.setter
    def bar_length(self, value: 'float'):
        self.wrapped.BarLength = float(value) if value else 0.0



'''_2157.py

Datum
'''


from mastapy._internal import constructor
from mastapy.system_model.part_model import _2153
from mastapy._internal.python_net import python_net_import

_DATUM = python_net_import('SMT.MastaAPI.SystemModel.PartModel', 'Datum')


__docformat__ = 'restructuredtext en'
__all__ = ('Datum',)


class Datum(_2153.Component):
    '''Datum

    This is a mastapy class.
    '''

    TYPE = _DATUM

    __hash__ = None

    def __init__(self, instance_to_wrap: 'Datum.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def offset(self) -> 'float':
        '''float: 'Offset' is the original name of this property.'''

        return self.wrapped.Offset

    @offset.setter
    def offset(self, value: 'float'):
        self.wrapped.Offset = float(value) if value else 0.0

    @property
    def drawing_diameter(self) -> 'float':
        '''float: 'DrawingDiameter' is the original name of this property.'''

        return self.wrapped.DrawingDiameter

    @drawing_diameter.setter
    def drawing_diameter(self, value: 'float'):
        self.wrapped.DrawingDiameter = float(value) if value else 0.0



'''_2255.py

StraightBevelGearSet
'''


from typing import List

from mastapy.gears.gear_designs.straight_bevel import _905
from mastapy._internal import constructor, conversion
from mastapy.system_model.part_model.gears import _2254, _2227
from mastapy.system_model.connections_and_sockets.gears import _2036
from mastapy._internal.python_net import python_net_import

_STRAIGHT_BEVEL_GEAR_SET = python_net_import('SMT.MastaAPI.SystemModel.PartModel.Gears', 'StraightBevelGearSet')


__docformat__ = 'restructuredtext en'
__all__ = ('StraightBevelGearSet',)


class StraightBevelGearSet(_2227.BevelGearSet):
    '''StraightBevelGearSet

    This is a mastapy class.
    '''

    TYPE = _STRAIGHT_BEVEL_GEAR_SET

    __hash__ = None

    def __init__(self, instance_to_wrap: 'StraightBevelGearSet.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def conical_gear_set_design(self) -> '_905.StraightBevelGearSetDesign':
        '''StraightBevelGearSetDesign: 'ConicalGearSetDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_905.StraightBevelGearSetDesign)(self.wrapped.ConicalGearSetDesign) if self.wrapped.ConicalGearSetDesign else None

    @property
    def straight_bevel_gear_set_design(self) -> '_905.StraightBevelGearSetDesign':
        '''StraightBevelGearSetDesign: 'StraightBevelGearSetDesign' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_905.StraightBevelGearSetDesign)(self.wrapped.StraightBevelGearSetDesign) if self.wrapped.StraightBevelGearSetDesign else None

    @property
    def straight_bevel_gears(self) -> 'List[_2254.StraightBevelGear]':
        '''List[StraightBevelGear]: 'StraightBevelGears' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.StraightBevelGears, constructor.new(_2254.StraightBevelGear))
        return value

    @property
    def straight_bevel_meshes(self) -> 'List[_2036.StraightBevelGearMesh]':
        '''List[StraightBevelGearMesh]: 'StraightBevelMeshes' is the original name of this property.

        Note:
            This property is readonly.
        '''

        value = conversion.pn_to_mp_objects_in_list(self.wrapped.StraightBevelMeshes, constructor.new(_2036.StraightBevelGearMesh))
        return value



'''_1602.py

BearingCageMaterial
'''


from enum import Enum

from mastapy._internal.python_net import python_net_import

_BEARING_CAGE_MATERIAL = python_net_import('SMT.MastaAPI.Bearings', 'BearingCageMaterial')


__docformat__ = 'restructuredtext en'
__all__ = ('BearingCageMaterial',)


class BearingCageMaterial(Enum):
    '''BearingCageMaterial

    This is a mastapy class.

    Note:
        This class is an Enum.
    '''

    @classmethod
    def type_(cls):
        return _BEARING_CAGE_MATERIAL

    __hash__ = None

    STEEL = 0
    BRASS = 1
    PLASTIC = 2


def __enum_setattr(self, attr, value):
    raise AttributeError('Cannot set the attributes of an Enum.') from None


def __enum_delattr(self, attr):
    raise AttributeError('Cannot delete the attributes of an Enum.') from None


BearingCageMaterial.__setattr__ = __enum_setattr
BearingCageMaterial.__delattr__ = __enum_delattr



'''_1341.py

ForceAndDisplacementResults
'''


from mastapy.math_utility.measured_vectors import _1345, _1340
from mastapy._internal import constructor
from mastapy._internal.python_net import python_net_import

_FORCE_AND_DISPLACEMENT_RESULTS = python_net_import('SMT.MastaAPI.MathUtility.MeasuredVectors', 'ForceAndDisplacementResults')


__docformat__ = 'restructuredtext en'
__all__ = ('ForceAndDisplacementResults',)


class ForceAndDisplacementResults(_1340.AbstractForceAndDisplacementResults):
    '''ForceAndDisplacementResults

    This is a mastapy class.
    '''

    TYPE = _FORCE_AND_DISPLACEMENT_RESULTS

    __hash__ = None

    def __init__(self, instance_to_wrap: 'ForceAndDisplacementResults.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def displacement(self) -> '_1345.VectorWithLinearAndAngularComponents':
        '''VectorWithLinearAndAngularComponents: 'Displacement' is the original name of this property.

        Note:
            This property is readonly.
        '''

        return constructor.new(_1345.VectorWithLinearAndAngularComponents)(self.wrapped.Displacement) if self.wrapped.Displacement else None
